@@ -44,16 +44,16 @@ class VBox:
 	def validate_virt(self):
 		# Determine which version of VirtualBox we have installed.  What is returned is
 		# typically a string such as '3.1.0r55467', lets assume that the command line
-		# is consistent within 3.0.x versions and 3.1.x version so extract this part of the
+		# is consistent within 3.1.x, 3.2.x and 4.0.x versions extract this part of the
 		# version string for comparison later
 		self.vboxversion = commands.getoutput("VBoxManage --version")
-		self.vboxversion = "%s.%s" % (self.vboxversion.split(".")[0], self.vboxversion.split(".")[1])
-		if self.vboxversion == "3.0" or self.vboxversion == "3.1" or self.vboxversion == "3.2":
+		self.vboxversion = ( int(self.vboxversion.split(".")[0]), int(self.vboxversion.split(".")[1]) )
+		if self.vboxversion == (3,1) or self.vboxversion == (3,2) or self.vboxversion == (4,0):
 			#info("VirtualBox %s detected." % self.vboxversion)
-			print "INFO: VirtualBox %s detected." % self.vboxversion
+			print "INFO: VirtualBox %s.%s detected." % self.vboxversion
 		else:
 			#error("Unsupported version (%s) of VirtualBox; please install v3.0 or v3.1." % self.vboxversion)
-			print "ERROR: Unsupported version (%s) of VirtualBox; please install v3.0, v3.1 or v3.2." % self.vboxversion
+			print "ERROR: Unsupported version (%s.%s) of VirtualBox; please install v3.1, v3.2 or v4.0." % self.vboxversion
 			exit(0)
 
 	# Code to setup virtual machine
@@ -66,9 +66,7 @@ class VBox:
 			#info("Creating disk image...")
 			print "INFO: Creating disk image..."
 			self.run_or_die("VBoxManage createhd --filename %s --size %s" % (self.DISK_FILE, self.DISK_SIZE))
-		if self.vboxversion == "3.0":
-			self.run("VBoxManage modifyvm %s --hda none" % self.VBOX_NAME)
-		elif self.vboxversion == "3.1" or self.vboxversion == "3.2":
+		if self.vboxversion == (3,1) or self.vboxversion == (3,2) or self.vboxversion == (4,0):
 			self.run("VBoxManage storageattach %s --storagectl \"IDE Controller\" --port 0 --device 0 --type hdd --medium none" % self.VBOX_NAME)
 			if self.PATH_TO_ISO != "/dev/null":
 				self.run("VBoxManage storageattach %s --storagectl \"IDE Controller\" --port 0 --device 1 --type dvddrive --medium none" % self.VBOX_NAME)
@@ -94,13 +92,7 @@ class VBox:
 	def launch_virt(self):
 		#info("Running the Virtual Machine...")
 		print "Running the Virtual Machine..."
-		if self.vboxversion == "3.0":
-			self.run_or_die("VBoxManage modifyvm %s --hda %s" % (self.VBOX_NAME, self.DISK_FILE))
-			self.run_or_die("VBoxManage startvm %s" % self.VBOX_NAME)
-			if self.PATH_TO_ISO != "/dev/null":
-				print(">>> %s <<<\n" % (self.PATH_TO_ISO))
-				self.run_or_die("VBoxManage controlvm %s dvdattach %s" % (self.VBOX_NAME, self.PATH_TO_ISO))
-		elif self.vboxversion == "3.1" or self.vboxversion == "3.2":
+		if self.vboxversion == (3,1) or self.vboxversion == (3,2) or self.vboxversion == (4,0):
 			self.run_or_die("VBoxManage storagectl %s --name \"IDE Controller\" --add ide" % self.VBOX_NAME)
 			self.run_or_die("VBoxManage storageattach %s --storagectl \"IDE Controller\" --port 0 --device 0 --type hdd --medium %s" % (self.VBOX_NAME, self.DISK_FILE))
 			if self.PATH_TO_ISO != "/dev/null":
